pub enum InteropError {
Show 25 variants
NotImplemented,
ValueMismatch {
value: Box<ScriptValue>,
expected: Box<TypeId>,
},
LengthMismatch {
expected: usize,
got: usize,
},
FailedFromReflect {
type_id: Box<Option<TypeId>>,
reason: Box<String>,
},
TypeMismatch {
expected: Box<TypeId>,
got: Box<Option<TypeId>>,
},
StringTypeMismatch {
expected: Box<String>,
got: Box<Option<TypeId>>,
},
CannotClaimAccess {
base: Box<WorldAccessRangeWithDisplay>,
context: Box<Cow<'static, str>>,
},
Invariant(Box<String>),
UnregisteredComponentOrResourceType {
type_: Box<TypeId>,
},
MissingResource {
type_: Box<TypeId>,
},
UnsupportedOperation {
base: Box<Option<TypeId>>,
value: Box<Option<ReflectWrapper>>,
operation: Box<String>,
},
MissingTypeData {
type_id: Box<TypeId>,
type_data: Box<String>,
},
MissingEntity(Entity),
FunctionInteropError {
function_name: Box<String>,
on: Box<Namespace>,
error: Box<InteropError>,
context: Box<Option<FunctionCallContext>>,
},
FunctionArgConversionError {
argument: Box<String>,
error: Box<InteropError>,
},
ArgumentCountMismatch {
expected: usize,
got: usize,
},
GarbageCollectedAllocation {
reference: Box<ReflectReference>,
},
UnregisteredReflectBase {
base: Box<ReflectBaseType>,
},
ReflectionPathError {
error: Box<String>,
reflected: Option<Box<ReflectReference>>,
},
CouldNotDowncastReference {
to: Box<TypeId>,
reference: Box<ReflectReference>,
},
MissingSchedule {
schedule_name: &'static str,
},
InvalidIndex {
index: Box<ScriptValue>,
reason: Box<String>,
},
MissingWorld,
External(ExternalError),
WithContext(Box<Cow<'static, str>>, Box<InteropError>),
}Expand description
An error occurring when converting between rust and a script context.
Variants
NotImplemented
The given feature is not implemented
ValueMismatch
A script value was of the wrong type
LengthMismatch
The length of a list like structure was wrong
FailedFromReflect
Something failed when converting from a reflect
Fields
TypeMismatch
A type mismatch occurred
StringTypeMismatch
A type mismatch occurred, but with a string representation of the expected type
CannotClaimAccess
Could not claim access to a value
Fields
base: Box<WorldAccessRangeWithDisplay>The id of the access
Invariant(Box<String>)
An invariant was broken
UnregisteredComponentOrResourceType
An unregistered component or resource type was used
MissingResource
A resource is registered, but not inserted
UnsupportedOperation
An unsupported operation was performed
Fields
value: Box<Option<ReflectWrapper>>The value of the operation
MissingTypeData
Some type data was missing
Fields
MissingEntity(Entity)
An entity was missing
FunctionInteropError
An error occurred in a function
Fields
error: Box<InteropError>The error that occurred
context: Box<Option<FunctionCallContext>>The context at the time of the call
FunctionArgConversionError
An error occurred when converting a function argument
Fields
error: Box<InteropError>The error that occurred
ArgumentCountMismatch
The number of arguments in a function call was wrong
GarbageCollectedAllocation
A garbage collected allocation was used
Fields
reference: Box<ReflectReference>The reference to the allocation
UnregisteredReflectBase
An unregistered reflect base was used
Fields
base: Box<ReflectBaseType>The base that was unregistered
ReflectionPathError
An error occurred when using a reflection path
Fields
reflected: Option<Box<ReflectReference>>The reflected value
CouldNotDowncastReference
Could not downcast a reference
Fields
reference: Box<ReflectReference>The reference to downcast
MissingSchedule
A schedule was missing
InvalidIndex
An invalid index was used
Fields
index: Box<ScriptValue>The index that was invalid
MissingWorld
The world was missing
External(ExternalError)
An external error occurred
WithContext(Box<Cow<'static, str>>, Box<InteropError>)
an error enriched with some contextual information
Implementations
Sourceimpl InteropError
impl InteropError
Sourcepub fn unwrap_context(self) -> (Vec<Cow<'static, str>>, InteropError)
pub fn unwrap_context(self) -> (Vec<Cow<'static, str>>, InteropError)
Strips outer context layers from the error, returning all contexts and the base error
Sourcepub fn with_context(self, context: impl Into<Cow<'static, str>>) -> Self
pub fn with_context(self, context: impl Into<Cow<'static, str>>) -> Self
Adds context to an existing error
Sourcepub fn external(error: impl Error + Send + Sync + 'static) -> Self
pub fn external(error: impl Error + Send + Sync + 'static) -> Self
Creates a new external error.
Sourcepub fn external_boxed(error: Box<dyn Error + Send + Sync + 'static>) -> Self
pub fn external_boxed(error: Box<dyn Error + Send + Sync + 'static>) -> Self
Creates a new external error from a boxed error.
Sourcepub fn value_mismatch(expected: TypeId, value: ScriptValue) -> Self
pub fn value_mismatch(expected: TypeId, value: ScriptValue) -> Self
Creates a new value mismatch error.
Sourcepub fn length_mismatch(expected: usize, got: usize) -> Self
pub fn length_mismatch(expected: usize, got: usize) -> Self
Creates a new length mismatch error.
Sourcepub fn failed_from_reflect(
type_id: Option<TypeId>,
reason: impl Display,
) -> Self
pub fn failed_from_reflect( type_id: Option<TypeId>, reason: impl Display, ) -> Self
Creates a new failed from reflect error.
Sourcepub fn type_mismatch(expected: TypeId, got: Option<TypeId>) -> Self
pub fn type_mismatch(expected: TypeId, got: Option<TypeId>) -> Self
Creates a new type mismatch error.
Sourcepub fn string_type_mismatch(expected: String, got: Option<TypeId>) -> Self
pub fn string_type_mismatch(expected: String, got: Option<TypeId>) -> Self
Creates a new string type mismatch error.
Sourcepub fn cannot_claim_access(
base: WorldAccessRange,
context: impl Into<Cow<'static, str>>,
) -> Self
pub fn cannot_claim_access( base: WorldAccessRange, context: impl Into<Cow<'static, str>>, ) -> Self
Creates a new cannot claim access error.
Sourcepub fn unregistered_component_or_resource_type(type_id: TypeId) -> Self
pub fn unregistered_component_or_resource_type(type_id: TypeId) -> Self
Creates a new unregistered component or resource type error.
Sourcepub fn missing_resource(type_id: TypeId) -> Self
pub fn missing_resource(type_id: TypeId) -> Self
Creates a new missing resource type error.
Sourcepub fn unsupported_operation(
base: Option<TypeId>,
value: Option<Box<dyn PartialReflect>>,
op: impl Display,
) -> Self
pub fn unsupported_operation( base: Option<TypeId>, value: Option<Box<dyn PartialReflect>>, op: impl Display, ) -> Self
Creates a new unsupported operation error.
Sourcepub fn missing_type_data(type_id: TypeId, type_data: String) -> Self
pub fn missing_type_data(type_id: TypeId, type_data: String) -> Self
Creates a new missing type data error.
Sourcepub fn missing_entity(entity: Entity) -> Self
pub fn missing_entity(entity: Entity) -> Self
Creates a new missing entity error.
Sourcepub fn reflect_apply_error(e: ApplyError) -> Self
pub fn reflect_apply_error(e: ApplyError) -> Self
Creates a new reflect apply error.
Sourcepub fn function_interop_error(
function_name: impl Display,
on: Namespace,
error: InteropError,
context: Option<FunctionCallContext>,
) -> Self
pub fn function_interop_error( function_name: impl Display, on: Namespace, error: InteropError, context: Option<FunctionCallContext>, ) -> Self
Creates a new function interop error.
Sourcepub fn function_arg_conversion_error(
argument: String,
error: InteropError,
) -> Self
pub fn function_arg_conversion_error( argument: String, error: InteropError, ) -> Self
Thrown when an error happens during argument conversion in a function call
Sourcepub fn argument_count_mismatch(expected: usize, got: usize) -> Self
pub fn argument_count_mismatch(expected: usize, got: usize) -> Self
Thrown when the number of arguments in a function call does not match.
Sourcepub fn garbage_collected_allocation(reference: ReflectReference) -> Self
pub fn garbage_collected_allocation(reference: ReflectReference) -> Self
Creates a new garbage collected allocation error.
Sourcepub fn unregistered_base(base: ReflectBaseType) -> Self
pub fn unregistered_base(base: ReflectBaseType) -> Self
Creates a new unregistered base error.
Sourcepub fn reflection_path_error(
error: String,
reflected: Option<ReflectReference>,
) -> Self
pub fn reflection_path_error( error: String, reflected: Option<ReflectReference>, ) -> Self
Creates a new reflection path error.
Sourcepub fn could_not_downcast(reference: ReflectReference, to: TypeId) -> Self
pub fn could_not_downcast(reference: ReflectReference, to: TypeId) -> Self
Creates a new could not downcast error.
Sourcepub fn missing_schedule(schedule_name: &'static str) -> Self
pub fn missing_schedule(schedule_name: &'static str) -> Self
Creates a new missing schedule error.
Sourcepub fn invalid_index(index: ScriptValue, reason: impl Into<String>) -> Self
pub fn invalid_index(index: ScriptValue, reason: impl Into<String>) -> Self
Creates a new invalid index error.
Sourcepub fn missing_world() -> Self
pub fn missing_world() -> Self
Creates a new missing world error.
Sourcepub fn missing_function(
function_name: impl Display,
on: Namespace,
context: Option<FunctionCallContext>,
) -> Self
pub fn missing_function( function_name: impl Display, on: Namespace, context: Option<FunctionCallContext>, ) -> Self
Creates a new missing function error.