pub struct ExternalError(pub Arc<dyn Error + Send + Sync>);Expand description
An error that occurred in an external library.
Tuple Fields
0: Arc<dyn Error + Send + Sync>Trait Implementations
Sourceimpl Clone for ExternalError
impl Clone for ExternalError
Sourcefn clone(&self) -> ExternalError
fn clone(&self) -> ExternalError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl DebugWithTypeInfo for ExternalError
impl DebugWithTypeInfo for ExternalError
Sourcefn to_string_with_type_info(
&self,
f: &mut Formatter<'_>,
_type_info_provider: Option<&WorldGuard<'_>>,
) -> Result
fn to_string_with_type_info( &self, f: &mut Formatter<'_>, _type_info_provider: Option<&WorldGuard<'_>>, ) -> Result
Format the value using the provided type info provider if available
Sourceimpl DisplayWithTypeInfo for ExternalError
impl DisplayWithTypeInfo for ExternalError
Sourcefn display_with_type_info(
&self,
f: &mut Formatter<'_>,
_type_info_provider: Option<&WorldGuard<'_>>,
) -> Result
fn display_with_type_info( &self, f: &mut Formatter<'_>, _type_info_provider: Option<&WorldGuard<'_>>, ) -> Result
Format the value using the provided type info provider if available