M

pub struct M<'w, T>(pub &'w mut T);
A wrapper around a mutable reference to a value of type T.

This can be used to retrieve a mutable reference out of a ScriptValue::Reference corresponding to the type T. Before downcasting the reference, it will claim write access to the object to ensure that the reference is valid.

However, the access is NOT released when the Mut is dropped. This is not unsafe but can lead to deadlocks if not released later. The [ScriptFunction] calling mechanism will take care of releasing all accesses claimed during the function call.

Tuple Fields

0: &'w mut T