Module script_function

Module script_function 

Implementations of the ScriptFunction and ScriptFunctionMut traits for functions with up to 13 arguments.

Structs

AppScriptFunctionRegistry
Equivalent to AppScriptFunctionRegistry but stores functions with a more convenient signature for scripting to avoid boxing every argument.
DummyScriptFunctionRegistry
Identical to the AppScriptFunctionRegistry, but the functions only exist for docs purposes, use if you provide functions at a lower level, but still want to include the function in the docs
DynamicScriptFunction
A dynamic script function.
DynamicScriptFunctionMut
A dynamic mutable script function.
FunctionCallContext
The caller context when calling a script function. Functions can choose to react to caller preferences such as converting 1-indexed numbers to 0-indexed numbers
FunctionKey
A key used to identify a function in the registry
LocationContext
Describes a location within a script
ScriptFunctionRegistry
A registry of dynamic script functions
ScriptFunctionRegistryArc
A thread-safe reference counted wrapper around a ScriptFunctionRegistry

Traits

ScriptFunction
A trait implemented by functions which can act as dynamic script functions, which can then be registered against a ScriptFunctionRegistry.
ScriptFunctionMut
A trait implemented by functions which can act as mutable dynamic script functions.