pub struct DynamicScriptFunctionMut {
pub info: Arc<FunctionInfo>,
/* private fields */
}Expand description
A dynamic mutable script function.
Fields
info: Arc<FunctionInfo>The meta information about the function
Implementations
Sourceimpl DynamicScriptFunctionMut
impl DynamicScriptFunctionMut
Sourcepub fn call<I: IntoIterator<Item = ScriptValue>>(
&self,
args: I,
context: FunctionCallContext,
) -> Result<ScriptValue, InteropError>
pub fn call<I: IntoIterator<Item = ScriptValue>>( &self, args: I, context: FunctionCallContext, ) -> Result<ScriptValue, InteropError>
Call the function with the given arguments and caller context.
In the case of errors wraps the error in a InteropError::function_interop_error to provide more context.
Sourcepub fn with_info(self, info: FunctionInfo) -> Self
pub fn with_info(self, info: FunctionInfo) -> Self
Set the meta information about the function