Module path

Module path 

BMS native reflection paths

Structs

ReferencePath
A collection of references into a Reflect supporting trait object in series.
ReferencePathError
Errors to do with custom BMS reference path resolution.

Enums

ReferencePart
A key referencing into a Reflect supporting trait object.