ScriptComponentRegistration

Struct ScriptComponentRegistration 

pub struct ScriptComponentRegistration {
    pub registration: ScriptTypeRegistration,
    pub component_id: ComponentId,
    pub is_dynamic_script_component: bool,
}
A reference to a component type’s reflection registration.

In general think of this as a handle to a type.

Not to be confused with script registered dynamic components, although this can point to a script registered component.

Fields

registration: ScriptTypeRegistration

The type registration of the component

component_id: ComponentId

the component id of the component

is_dynamic_script_component: bool

whether this is a component registered BY a script

Implementations

Source

impl ScriptComponentRegistration

pub fn new( registration: ScriptTypeRegistration, component_id: ComponentId, ) -> Self

pub fn component_id(&self) -> ComponentId

Returns the ComponentId for this type, if it is a component.

pub fn type_registration(&self) -> &ScriptTypeRegistration

Returns the ScriptTypeRegistration for this type.

pub fn into_type_registration(self) -> ScriptTypeRegistration

Convert to a generic ScriptTypeRegistration ditching the component information.

pub fn remove_from_entity( &self, world: WorldGuard<'_>, entity: Entity, ) -> Result<(), InteropError>

Removes an instance of this component from the given entity

pub fn insert_into_entity( &self, world: WorldGuard<'_>, entity: Entity, instance: Box<dyn Reflect>, ) -> Result<(), InteropError>

Inserts an instance of this component into the given entity

Requires whole world access