This module contains the ScriptValue enum which is used to pass values between scripting languages and Rust.
Structs
- Variadic
Tuple - A tuple variant of script value
Enums
- Script
Value - An abstraction of values that can be passed to and from scripts. This allows us to re-use logic between scripting languages.