pub struct VariadicTuple(pub VecDeque<ScriptValue>);Expand description
A tuple variant of script value
Tuple Fields
0: VecDeque<ScriptValue>Trait Implementations
Sourceimpl ArgMeta for VariadicTuple
impl ArgMeta for VariadicTuple
Sourcefn default_value() -> Option<ScriptValue>
fn default_value() -> Option<ScriptValue>
The default value for the argument. Used when the argument is not provided.
Sourceimpl Clone for VariadicTuple
impl Clone for VariadicTuple
Sourcefn clone(&self) -> VariadicTuple
fn clone(&self) -> VariadicTuple
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VariadicTuple
impl Debug for VariadicTuple
Sourceimpl DebugWithTypeInfo for VariadicTuple
impl DebugWithTypeInfo for VariadicTuple
Sourcefn to_string_with_type_info(
&self,
f: &mut Formatter<'_>,
type_info_provider: Option<&WorldAccessGuard<'_>>,
) -> Result
fn to_string_with_type_info( &self, f: &mut Formatter<'_>, type_info_provider: Option<&WorldAccessGuard<'_>>, ) -> Result
Format the value using the provided type info provider if available
Sourceimpl Default for VariadicTuple
impl Default for VariadicTuple
Sourcefn default() -> VariadicTuple
fn default() -> VariadicTuple
Returns the “default value” for a type. Read more
Sourceimpl FromReflect for VariadicTuple
impl FromReflect for VariadicTuple
Sourcefn from_reflect(reflect: &dyn PartialReflect) -> Option<Self>
fn from_reflect(reflect: &dyn PartialReflect) -> Option<Self>
Constructs a concrete instance of
Self from a reflected value.Sourcefn take_from_reflect(
reflect: Box<dyn PartialReflect>,
) -> Result<Self, Box<dyn PartialReflect>>
fn take_from_reflect( reflect: Box<dyn PartialReflect>, ) -> Result<Self, Box<dyn PartialReflect>>
Attempts to downcast the given value to
Self using,
constructing the value using from_reflect if that fails. Read moreSourceimpl FromScript for VariadicTuple
impl FromScript for VariadicTuple
Sourcetype This<'w> = VariadicTuple
type This<'w> = VariadicTuple
The type that is constructed from the script value.
Sourcefn from_script(
value: ScriptValue,
_world: WorldGuard<'_>,
) -> Result<Self::This<'_>, InteropError>where
Self: Sized,
fn from_script(
value: ScriptValue,
_world: WorldGuard<'_>,
) -> Result<Self::This<'_>, InteropError>where
Self: Sized,
Construct a value of type
T from a ScriptValue.Sourceimpl GetTypeDependencies for VariadicTuple
impl GetTypeDependencies for VariadicTuple
Sourcetype Underlying = VariadicTuple
type Underlying = VariadicTuple
In the majority of the implementations, this will be
Self
However some types might be facades for other types, in which case this will be the underlying typeSourcefn register_type_dependencies(registry: &mut TypeRegistry)
fn register_type_dependencies(registry: &mut TypeRegistry)
Registers the type dependencies of the implementing type with the given
TypeRegistry.Sourceimpl GetTypeRegistration for VariadicTuple
impl GetTypeRegistration for VariadicTuple
Sourcefn get_type_registration() -> TypeRegistration
fn get_type_registration() -> TypeRegistration
Returns the default
TypeRegistration for this type.Sourcefn register_type_dependencies(_registry: &mut TypeRegistry)
fn register_type_dependencies(_registry: &mut TypeRegistry)
Registers other types needed by this type. Read more
Sourceimpl IntoScript for VariadicTuple
impl IntoScript for VariadicTuple
Sourcefn into_script(
self,
_world: WorldGuard<'_>,
) -> Result<ScriptValue, InteropError>
fn into_script( self, _world: WorldGuard<'_>, ) -> Result<ScriptValue, InteropError>
Convert this value into a
ScriptValue.Sourcefn into_script_inline_error(self, world: WorldGuard<'_>) -> ScriptValuewhere
Self: Sized,
fn into_script_inline_error(self, world: WorldGuard<'_>) -> ScriptValuewhere
Self: Sized,
Convert this value into a
ScriptValue, returning an error as a ScriptValue if an error occurs.Sourceimpl PartialReflect for VariadicTuple
impl PartialReflect for VariadicTuple
Sourcefn get_represented_type_info(&self) -> Option<&'static TypeInfo>
fn get_represented_type_info(&self) -> Option<&'static TypeInfo>
Sourcefn to_dynamic(&self) -> Box<dyn PartialReflect>
fn to_dynamic(&self) -> Box<dyn PartialReflect>
Sourcefn try_apply(&mut self, value: &dyn PartialReflect) -> Result<(), ApplyError>
fn try_apply(&mut self, value: &dyn PartialReflect) -> Result<(), ApplyError>
Sourcefn reflect_kind(&self) -> ReflectKind
fn reflect_kind(&self) -> ReflectKind
Returns a zero-sized enumeration of “kinds” of type. Read more
Sourcefn reflect_ref(&self) -> ReflectRef<'_>
fn reflect_ref(&self) -> ReflectRef<'_>
Returns an immutable enumeration of “kinds” of type. Read more
Sourcefn reflect_mut(&mut self) -> ReflectMut<'_>
fn reflect_mut(&mut self) -> ReflectMut<'_>
Returns a mutable enumeration of “kinds” of type. Read more
Sourcefn reflect_owned(self: Box<Self>) -> ReflectOwned
fn reflect_owned(self: Box<Self>) -> ReflectOwned
Returns an owned enumeration of “kinds” of type. Read more
Sourcefn try_into_reflect(
self: Box<Self>,
) -> Result<Box<dyn Reflect>, Box<dyn PartialReflect>>
fn try_into_reflect( self: Box<Self>, ) -> Result<Box<dyn Reflect>, Box<dyn PartialReflect>>
Attempts to cast this type to a boxed, fully-reflected value.
Sourcefn try_as_reflect(&self) -> Option<&dyn Reflect>
fn try_as_reflect(&self) -> Option<&dyn Reflect>
Attempts to cast this type to a fully-reflected value.
Sourcefn try_as_reflect_mut(&mut self) -> Option<&mut dyn Reflect>
fn try_as_reflect_mut(&mut self) -> Option<&mut dyn Reflect>
Attempts to cast this type to a mutable, fully-reflected value.
Sourcefn into_partial_reflect(self: Box<Self>) -> Box<dyn PartialReflect>
fn into_partial_reflect(self: Box<Self>) -> Box<dyn PartialReflect>
Casts this type to a boxed, reflected value. Read more
Sourcefn as_partial_reflect(&self) -> &dyn PartialReflect
fn as_partial_reflect(&self) -> &dyn PartialReflect
Casts this type to a reflected value. Read more
Sourcefn as_partial_reflect_mut(&mut self) -> &mut dyn PartialReflect
fn as_partial_reflect_mut(&mut self) -> &mut dyn PartialReflect
Casts this type to a mutable, reflected value. Read more
Sourcefn apply(&mut self, value: &(dyn PartialReflect + 'static))
fn apply(&mut self, value: &(dyn PartialReflect + 'static))
Applies a reflected value to this value. Read more
Sourcefn reflect_clone(&self) -> Result<Box<dyn Reflect>, ReflectCloneError>
fn reflect_clone(&self) -> Result<Box<dyn Reflect>, ReflectCloneError>
Attempts to clone
Self using reflection. Read moreSourcefn reflect_clone_and_take<T>(&self) -> Result<T, ReflectCloneError>
fn reflect_clone_and_take<T>(&self) -> Result<T, ReflectCloneError>
For a type implementing
PartialReflect, combines reflect_clone and
take in a useful fashion, automatically constructing an appropriate
ReflectCloneError if the downcast fails.Sourcefn reflect_hash(&self) -> Option<u64>
fn reflect_hash(&self) -> Option<u64>
Returns a hash of the value (which includes the type). Read more
Sourcefn reflect_partial_eq(
&self,
_value: &(dyn PartialReflect + 'static),
) -> Option<bool>
fn reflect_partial_eq( &self, _value: &(dyn PartialReflect + 'static), ) -> Option<bool>
Returns a “partial equality” comparison result. Read more
Sourcefn reflect_partial_cmp(
&self,
_value: &(dyn PartialReflect + 'static),
) -> Option<Ordering>
fn reflect_partial_cmp( &self, _value: &(dyn PartialReflect + 'static), ) -> Option<Ordering>
Returns a “partial comparison” result. Read more
Sourcefn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error>
fn debug(&self, f: &mut Formatter<'_>) -> Result<(), Error>
Debug formatter for the value. Read more
Sourcefn is_dynamic(&self) -> bool
fn is_dynamic(&self) -> bool
Indicates whether or not this type is a dynamic type. Read more
Sourceimpl Reflect for VariadicTuple
impl Reflect for VariadicTuple
Sourcefn as_any_mut(&mut self) -> &mut dyn Any
fn as_any_mut(&mut self) -> &mut dyn Any
Returns the value as a
&mut dyn Any. Read moreSourcefn into_reflect(self: Box<Self>) -> Box<dyn Reflect>
fn into_reflect(self: Box<Self>) -> Box<dyn Reflect>
Casts this type to a boxed, fully-reflected value.
Sourcefn as_reflect(&self) -> &dyn Reflect
fn as_reflect(&self) -> &dyn Reflect
Casts this type to a fully-reflected value.
Sourcefn as_reflect_mut(&mut self) -> &mut dyn Reflect
fn as_reflect_mut(&mut self) -> &mut dyn Reflect
Casts this type to a mutable, fully-reflected value.
Sourceimpl TypePath for VariadicTuple
impl TypePath for VariadicTuple
Sourcefn type_path() -> &'static str
fn type_path() -> &'static str
Returns the fully qualified path of the underlying type. Read more
Sourcefn short_type_path() -> &'static str
fn short_type_path() -> &'static str
Returns a short, pretty-print enabled path to the type. Read more
Sourcefn type_ident() -> Option<&'static str>
fn type_ident() -> Option<&'static str>
Sourcefn crate_name() -> Option<&'static str>
fn crate_name() -> Option<&'static str>
Sourceimpl Typed for VariadicTuple
impl Typed for VariadicTuple
Sourceimpl TypedThrough for VariadicTuple
impl TypedThrough for VariadicTuple
Sourcefn through_type_info() -> ThroughTypeInfo
fn through_type_info() -> ThroughTypeInfo
Get the
ThroughTypeInfo for the type.Auto Trait Implementations
impl !RefUnwindSafe for VariadicTuple
impl !UnwindSafe for VariadicTuple
impl Freeze for VariadicTuple
impl Send for VariadicTuple
impl Sync for VariadicTuple
impl Unpin for VariadicTuple
impl UnsafeUnpin for VariadicTuple