pub struct M<'w, T>(pub &'w mut T);Expand description
A wrapper around a mutable reference to a value of type T.
This can be used to retrieve a mutable reference out of a ScriptValue::Reference corresponding to the type T.
Before downcasting the reference, it will claim write access to the object to ensure that the reference is valid.
However, the access is NOT released when the Mut is dropped. This is not unsafe but can lead to deadlocks if not released later.
The [ScriptFunction] calling mechanism will take care of releasing all accesses claimed during the function call.
Tuple Fields
0: &'w mut TTrait Implementations
Sourceimpl<T> ArgMeta for M<'_, T>
impl<T> ArgMeta for M<'_, T>
Sourcefn default_value() -> Option<ScriptValue>
fn default_value() -> Option<ScriptValue>
The default value for the argument. Used when the argument is not provided.
Sourceimpl<T: FromReflect> FromScript for M<'_, T>
impl<T: FromReflect> FromScript for M<'_, T>
Sourcefn from_script(
value: ScriptValue,
world: WorldGuard<'_>,
) -> Result<Self::This<'_>, InteropError>
fn from_script( value: ScriptValue, world: WorldGuard<'_>, ) -> Result<Self::This<'_>, InteropError>
Construct a value of type
T from a ScriptValue.Sourceimpl<'a, T> GetTypeDependencies for M<'a, T>where
T: GetTypeRegistration,
impl<'a, T> GetTypeDependencies for M<'a, T>where
T: GetTypeRegistration,
Sourcetype Underlying = T
type Underlying = T
In the majority of the implementations, this will be
Self
However some types might be facades for other types, in which case this will be the underlying typeSourcefn register_type_dependencies(registry: &mut TypeRegistry)
fn register_type_dependencies(registry: &mut TypeRegistry)
Registers the type dependencies of the implementing type with the given
TypeRegistry.Sourceimpl<T: Typed> TypedThrough for M<'_, T>
impl<T: Typed> TypedThrough for M<'_, T>
Sourcefn through_type_info() -> ThroughTypeInfo
fn through_type_info() -> ThroughTypeInfo
Get the
ThroughTypeInfo for the type.Auto Trait Implementations
impl<'w, T> !UnwindSafe for M<'w, T>
impl<'w, T> Freeze for M<'w, T>
impl<'w, T> RefUnwindSafe for M<'w, T>where
T: RefUnwindSafe,
impl<'w, T> Send for M<'w, T>where
T: Send,
impl<'w, T> Sync for M<'w, T>where
T: Sync,
impl<'w, T> Unpin for M<'w, T>
impl<'w, T> UnsafeUnpin for M<'w, T>