Implementations of the ScriptFunction and ScriptFunctionMut traits for functions with up to 13 arguments.
Structs
- AppScript
Function Registry - Equivalent to
AppScriptFunctionRegistrybut stores functions with a more convenient signature for scripting to avoid boxing every argument. - Dummy
Script Function Registry - Identical to the
AppScriptFunctionRegistry, but the functions only exist for docs purposes, use if you provide functions at a lower level, but still want to include the function in the docs - Dynamic
Script Function - A dynamic script function.
- Dynamic
Script Function Mut - A dynamic mutable script function.
- Function
Call Context - The caller context when calling a script function. Functions can choose to react to caller preferences such as converting 1-indexed numbers to 0-indexed numbers
- Function
Key - A key used to identify a function in the registry
- Location
Context - Describes a location within a script
- Script
Function Registry - A registry of dynamic script functions
- Script
Function Registry Arc - A thread-safe reference counted wrapper around a
ScriptFunctionRegistry
Traits
- Script
Function - A trait implemented by functions which can act as dynamic script functions, which can then be registered against a
ScriptFunctionRegistry. - Script
Function Mut - A trait implemented by functions which can act as mutable dynamic script functions.