pub enum ScriptValue {
Unit,
Bool(bool),
Integer(i64),
Float(f64),
String(Cow<'static, str>),
List(VecDeque<ScriptValue>),
Tuple(VariadicTuple),
Map(HashMap<String, ScriptValue>),
Reference(ReflectReference),
FunctionMut(DynamicScriptFunctionMut),
Function(DynamicScriptFunction),
Error(InteropError),
}Expand description
An abstraction of values that can be passed to and from scripts. This allows us to re-use logic between scripting languages.
Variants
Unit
Represents the absence of a value.
Bool(bool)
Represents a boolean value.
Integer(i64)
Represents an integer value with at most 64 bits.
Float(f64)
Represents a floating point value with at most 64 bits.
String(Cow<'static, str>)
Represents a string value.
List(VecDeque<ScriptValue>)
Represents a list of other things passed by value
Tuple(VariadicTuple)
Represents a tuple of values, which is best intepreted as multiple non-homogenous values. If returned by a function, scripting languages supporting multiple return values can use this type to represent those.
Map(HashMap<String, ScriptValue>)
Represents a map of other things passed by value
Reference(ReflectReference)
Represents a reference to a value.
FunctionMut(DynamicScriptFunctionMut)
A dynamic script function possibly storing state. Preffer using the ScriptValue::Function variant instead if possible.
Function(DynamicScriptFunction)
A stateless dynamic script function
Error(InteropError)
Represents any error, will be thrown when returned to a script.
Implementations